@@ -243,7 +243,7 @@ class DAO():
         and if_dm=? and if_mentions=? and if_comments=?
         """
         sql2="""
-        order by created_at desc limit ? offset ?
+        order by created_at desc,status_id asc limit ? offset ?
         """
         sql=sql1
         if maxId!=None:
@@ -273,7 +273,7 @@ class DAO():
         and if_dm=? and if_mentions=? and if_comments=?
         """
         sql2="""
-        order by created_at desc limit ? offset ?
+        order by created_at desc,status_id asc limit ? offset ?
         """
         sql=sql1
         if pageflag==1:
@@ -365,6 +365,43 @@ class DAO():
         con.commit()
         c.close()
 
+    def del_status_by_cache(self):
+        sql = """
+        DELETE FROM status WHERE created_at <= datetime('now','-7 day')
+        """
+        con = self.get_connection()
+        c = con.cursor()
+        c.execute(sql)
+        c.execute("vacuum")
+        con.commit()
+        c.close()
+        
+
+    def save_settings(self,settings):
+        sql = """
+        UPDATE settings SET updatenum=:updatenum,downpic=:downpic
+        """
+        con = self.get_w_connection()
+        c = con.cursor()
+        c.execute(sql, settings)
+        con.commit()
+        self.logger.debug(c.rowcount)
+        c.close()
+        return settings
+        
+    def get_settings(self):
+        sql = """
+        SELECT * FROM settings limit 1
+        """
+        con = self.get_w_connection()
+        c = con.cursor()
+        c.execute(sql)
+        r = c.fetchone()
+        c.close()
+        s=Utils.build_settings_from_row(r)
+        return s
+        
+        
 
 if __name__ == "__main__":
     import sys
