@@ -158,8 +158,12 @@ class StatusModel(QAbstractListModel):
             return time
         if (role == Utils.ROLE_THUMBNAIL):
             thumbnailPic=status["thumbnail_pic"]
+            
             if thumbnailPic!=None:
                 filename=thumbnailPic.split("/")[-1]
+                if len(filename)==0 or filename=="460":
+                    filename=thumbnailPic.split("/")[-2]
+                    
                 thumbnailPic=Utils.THUMBNAIL_DIR+str(status["account"])+"_"+str(status["id"])+"_"+filename
                 if os.access(thumbnailPic, platform.os.W_OK) == 0:
                     thumbnailPic=None
