@@ -3,8 +3,8 @@
 __author__= "Michael Wong"
 __modify__= "Binkcn"
 __email__="binkcn@vip.qq.com"
-__version__= "0.2.3"
-__build__="110918"
+__version__= "0.3.1"
+__build__="110928"
 
 import platform
 import sys
@@ -17,7 +17,6 @@ import Utils
 from Models import *
 #from PyQt4.QtMaemo5 import *
 #from flickcharm import *
-from PyQt4.QtGui import *
 from PyQt4.QtMaemo5 import QMaemo5InformationBox
 
 
@@ -304,7 +303,6 @@ class DefaultCustomDelegate(QStyledItemDelegate):
         userImage=index.data(Utils.ROLE_AVATAR).toString()
         time=index.data(Utils.ROLE_TIME).toString()
 
-
         # Draw avatar
         avatar=QPixmap(userImage)
         painter.drawPixmap(x1 + self.leftMargin, y1 + self.topMargin, self.avatarWidth, self.avatarWidth, avatar)
@@ -330,6 +328,7 @@ class DefaultCustomDelegate(QStyledItemDelegate):
         painter.setPen(self.text_color)
         painter.setFont(self.normFont)
         thumbnailFile=index.data(Utils.ROLE_THUMBNAIL).toString()
+        
         if thumbnailFile=="":
             #just draw the text
             new_rect = \
@@ -709,7 +708,7 @@ class UserButton(QPushButton):
 
     def sizeHint(self):
         return QSize(780,70)
-
+    
     def paintEvent(self, event):
         super(UserButton, self).paintEvent(event)
         
@@ -731,7 +730,11 @@ class UserButton(QPushButton):
             userImage=Utils.AVATAR_DIR+str(self.status["account"])+"_"+str(user["id"])
             if platform.os.access(userImage, platform.os.W_OK) == 0:
                 userImage=Utils.DEFAULT_AVATAR_FILE
-            text=user["name"]+"\n"+user["location"]
+            text=user["name"]+"(@"+user["screen_name"]+")"
+            if user["verified"]==1:
+                text=text+" [认证用户]"
+            text=text+"\n"
+            text=text+"来自："+user["location"]+" 听众:"+str(user["followers_count"])+" 收听:"+str(user["friends_count"])+" 广播:"+str(user["statuses_count"])+""
 
         avatar=QPixmap(userImage)
         painter.drawPixmap(x1 + self.leftMargin, y1 + self.topMargin, self.avatarWidth, self.avatarWidth, avatar)
@@ -758,6 +761,7 @@ class StatusWindow(QMainWindow):
 
         self.statusContentView = StatusContentView(self,self.orientation)
         self.statusContentView.setFixedSize(770,270)
+        
         self.buttonFrame=QFrame()
         self.rtBtn = QPushButton(unicode("转发"))
         self.cmtBtn = QPushButton(unicode("评论"))
@@ -782,7 +786,6 @@ class StatusWindow(QMainWindow):
         self.setCentralWidget(self.mainFrame)
         self.setFixedSize(800,480)
 
-
     def switch(self,orientation):
         if orientation==self.orientation:
             return
@@ -822,7 +825,6 @@ class NewStatusWindow(QMainWindow):
         self.picPreBtn.setFixedSize(150,150)
 
 
-
 #        self.statusContentView = StatusContentView(self,self.orientation)
         self.avatarLabel=QLabel()
         self.avatarLabel.setFixedSize(70,180)
@@ -959,7 +961,7 @@ class NewStatusWindow(QMainWindow):
                     self.avatarLabel.setPixmap(QPixmap(rtUserImage))
                     self.statusLabel.setText(rtUser["name"]+" : "+rt["text"])
 
-                    text="//@"+status["user"]["name"]+":"+status["text"]
+                    text="||@"+status["user"]["name"]+":"+status["text"]
                     self.textEdit.setText(text)
                 else:
                     #retweet the original one.
@@ -1093,7 +1095,31 @@ class StatusContentView(QWebView):
 #        self.setRenderHint(QPainter.HighQualityAntialiasing)
         scroller=self.property("kineticScroller").toPyObject()
         scroller.setEnabled(True)
-
+        
+        self.page().setLinkDelegationPolicy(QWebPage.DelegateAllLinks)
+#        self.connect(self,
+#                     SIGNAL("loadFinished(bool)"),
+#                     self.loadfinished)
+        
+        self.connect(self,
+                     SIGNAL("linkClicked(const QUrl&)"),
+                     self.urlClicked)
+                     
+#    def loadfinished(self, strOK):
+#        print "debug!A!"
+#        print strOK
+        
+    def urlClicked(self, strUrl):
+        tmpURL = str(strUrl.toString())
+        
+        try:
+            import os
+            os.system('dbus-send --system --type=method_call --dest=com.nokia.osso_browser /com/nokia/osso_browser/request com.nokia.osso_browser.load_url string:"' + tmpURL + '"')
+        except:
+            print "Debug:"
+            print tmpURL
+            print "Maemo5 Broswer have a Bug."
+        
     #disable the right-click menu
     def contextMenuEvent (self, event):
         pass
@@ -1128,7 +1154,22 @@ class StatusContentView(QWebView):
             </tr>
             <tr>
                 <td width="100%" align="center">
-                    $pic
+                    <span id="tip"></span><br /><br />
+                    <img id="objpic" src="$spic" onclick="javascript:doLoadImage();" />
+                    <span style="display:none;" id="picurl">$pic</span>
+                    <script type="text/javascript">
+                        function doLoadImage(){
+                            document.getElementById('objpic').src = document.getElementById('picurl').innerHTML;
+                            document.getElementById('tip').innerHTML = 'Downloading...';
+                        }
+                        
+                        doInit();
+                        function doInit(){
+                            if (document.getElementById('objpic').src.length > 5){
+                                document.getElementById('tip').innerHTML = 'Double-click this image to download large image.';
+                            }
+                        }
+                    </script>
                 </td>
             </tr>
             $rt
@@ -1182,11 +1223,24 @@ class StatusContentView(QWebView):
         createdAt=status["created_at"]
 #        createdAtString=Utils.gene_datetime_string(createdAt)
         createdAtString=str(createdAt)
+        spic=status["thumbnail_pic"]
         pic=status["original_pic"]
         if pic==None:
             pic=""
+        
+        if spic!=None:
+            filename=spic.split("/")[-1]
+            if len(filename)==0 or filename=="460":
+                filename=spic.split("/")[-2]
+        
+            spic=Utils.THUMBNAIL_DIR+str(status["account"])+"_"+str(status["id"])+"_"+filename
+            if os.access(spic, platform.os.W_OK) == 0:
+                spic=""
+            else:
+                spic = "file:///" + spic
         else:
-            pic="<img src=\""+pic+"\"/>"
+            spic=""
+        
         rt=None
         rtUser=""
         rtName=""
@@ -1214,22 +1268,272 @@ class StatusContentView(QWebView):
         else:
             html=string.replace(html, "$rt", "")
 
+        text = self.parseURL(text, status["bmiddle_pic"])
         html=string.replace(html, "$text", text)
         html=string.replace(html, "$source", source)
         html=string.replace(html, "$createdAt", createdAtString)
+        html=string.replace(html, "$spic", spic)
         html=string.replace(html, "$pic", pic)
         if rt!=None:
+            rtText = self.parseURL(rtText, status["bmiddle_pic"])
             html=string.replace(html, "$rtText", "@"+rtName+" : "+rtText)
         else:
             html=string.replace(html, "$rtText", "")
         html=string.replace(html, "$rtPic", rtPic)
         html=string.replace(html, "$rtAvatar", rtAvatar)
-#        print html
+        html=self.repFace(html, status["bmiddle_pic"])
+        #print html
         self.setHtml(html)
 
+    def parseURL(self, html, strer):
+        if strer==None:
+            strer=""
+            
+        if len(strer)==10:
+            return html
+        else:
+            import re
+            html = re.sub(r"(http:\/\/t.cn/\w+)", r"<a target='_blank' href='\1'>\1</a>", html)
+            return html
+            
 
+    def repFace(self, html, strer):
+        if strer==None:
+            strer=""
+            
+        if len(strer)==10:
+            facePath = Utils.ICONS_DIR+"face.qq/"
+            
+            html = string.replace(html, "/惊讶", "<img src=\"file:///"+facePath+"0.gif\"/>")
+            html = string.replace(html, "/撇嘴", "<img src=\"file:///"+facePath+"1.gif\"/>")
+            html = string.replace(html, "/色", "<img src=\"file:///"+facePath+"2.gif\"/>")
+            html = string.replace(html, "/发呆", "<img src=\"file:///"+facePath+"3.gif\"/>")
+            html = string.replace(html, "/得意", "<img src=\"file:///"+facePath+"4.gif\"/>")
+            html = string.replace(html, "/流泪", "<img src=\"file:///"+facePath+"5.gif\"/>")
+            html = string.replace(html, "/羞涩", "<img src=\"file:///"+facePath+"6.gif\"/>")
+            html = string.replace(html, "/闭嘴", "<img src=\"file:///"+facePath+"7.gif\"/>")
+            html = string.replace(html, "/睡", "<img src=\"file:///"+facePath+"8.gif\"/>")
+            html = string.replace(html, "/大哭", "<img src=\"file:///"+facePath+"9.gif\"/>")
+            html = string.replace(html, "/尴尬", "<img src=\"file:///"+facePath+"10.gif\"/>")
+            html = string.replace(html, "/发怒", "<img src=\"file:///"+facePath+"11.gif\"/>")
+            html = string.replace(html, "/调皮", "<img src=\"file:///"+facePath+"12.gif\"/>")
+            html = string.replace(html, "/呲牙", "<img src=\"file:///"+facePath+"13.gif\"/>")
+            html = string.replace(html, "/微笑", "<img src=\"file:///"+facePath+"14.gif\"/>")
+            html = string.replace(html, "/难过", "<img src=\"file:///"+facePath+"15.gif\"/>")
+            html = string.replace(html, "/酷", "<img src=\"file:///"+facePath+"16.gif\"/>")
+            #html = string.replace(html, "/口罩", "<img src=\"file:///"+facePath+"17.gif\"/>")
+            html = string.replace(html, "/抓狂", "<img src=\"file:///"+facePath+"18.gif\"/>")
+            html = string.replace(html, "/吐", "<img src=\"file:///"+facePath+"19.gif\"/>")
+            html = string.replace(html, "/偷笑", "<img src=\"file:///"+facePath+"20.gif\"/>")
+            html = string.replace(html, "/可爱", "<img src=\"file:///"+facePath+"21.gif\"/>")
+            html = string.replace(html, "/白眼", "<img src=\"file:///"+facePath+"22.gif\"/>")
+            html = string.replace(html, "/傲慢", "<img src=\"file:///"+facePath+"23.gif\"/>")
+            html = string.replace(html, "/饥饿", "<img src=\"file:///"+facePath+"24.gif\"/>")
+            html = string.replace(html, "/困", "<img src=\"file:///"+facePath+"25.gif\"/>")
+            html = string.replace(html, "/惊恐", "<img src=\"file:///"+facePath+"26.gif\"/>")
+            html = string.replace(html, "/流汗", "<img src=\"file:///"+facePath+"27.gif\"/>")
+            html = string.replace(html, "/憨笑", "<img src=\"file:///"+facePath+"28.gif\"/>")
+            html = string.replace(html, "/大兵", "<img src=\"file:///"+facePath+"29.gif\"/>")
+            html = string.replace(html, "/奋斗", "<img src=\"file:///"+facePath+"30.gif\"/>")
+            html = string.replace(html, "/诅咒", "<img src=\"file:///"+facePath+"31.gif\"/>")
+            html = string.replace(html, "/疑问", "<img src=\"file:///"+facePath+"32.gif\"/>")
+            html = string.replace(html, "/嘘…", "<img src=\"file:///"+facePath+"33.gif\"/>")
+            html = string.replace(html, "/晕", "<img src=\"file:///"+facePath+"34.gif\"/>")
+            html = string.replace(html, "/折磨", "<img src=\"file:///"+facePath+"35.gif\"/>")
+            html = string.replace(html, "/衰", "<img src=\"file:///"+facePath+"36.gif\"/>")
+            html = string.replace(html, "/骷髅", "<img src=\"file:///"+facePath+"37.gif\"/>")
+            html = string.replace(html, "/敲打", "<img src=\"file:///"+facePath+"38.gif\"/>")
+            html = string.replace(html, "/再见", "<img src=\"file:///"+facePath+"39.gif\"/>")
+            #html = string.replace(html, "/XXXX", "<img src=\"file:///"+facePath+"40.gif\"/>")
+            html = string.replace(html, "/发抖", "<img src=\"file:///"+facePath+"41.gif\"/>")
+            html = string.replace(html, "/爱情", "<img src=\"file:///"+facePath+"42.gif\"/>")
+            html = string.replace(html, "/跳跳", "<img src=\"file:///"+facePath+"43.gif\"/>")
+            #html = string.replace(html, "/查找", "<img src=\"file:///"+facePath+"44.gif\"/>")
+            #html = string.replace(html, "/女Q", "<img src=\"file:///"+facePath+"45.gif\"/>")
+            html = string.replace(html, "/猪头", "<img src=\"file:///"+facePath+"46.gif\"/>")
+            #html = string.replace(html, "/猫咪", "<img src=\"file:///"+facePath+"47.gif\"/>")
+            #html = string.replace(html, "/狗", "<img src=\"file:///"+facePath+"48.gif\"/>")
+            html = string.replace(html, "/拥抱", "<img src=\"file:///"+facePath+"49.gif\"/>")
+            #html = string.replace(html, "/钱", "<img src=\"file:///"+facePath+"50.gif\"/>")
+            #html = string.replace(html, "/灯泡", "<img src=\"file:///"+facePath+"51.gif\"/>")
+            #html = string.replace(html, "/酒杯", "<img src=\"file:///"+facePath+"52.gif\"/>")
+            html = string.replace(html, "/蛋糕", "<img src=\"file:///"+facePath+"53.gif\"/>")
+            html = string.replace(html, "/闪电", "<img src=\"file:///"+facePath+"54.gif\"/>")
+            html = string.replace(html, "/炸弹", "<img src=\"file:///"+facePath+"55.gif\"/>")
+            html = string.replace(html, "/刀", "<img src=\"file:///"+facePath+"56.gif\"/>")
+            html = string.replace(html, "/足球", "<img src=\"file:///"+facePath+"57.gif\"/>")
+            #html = string.replace(html, "/音乐", "<img src=\"file:///"+facePath+"58.gif\"/>")
+            #html = string.replace(html, "/大便", "<img src=\"file:///"+facePath+"59.gif\"/>")
+            html = string.replace(html, "/咖啡", "<img src=\"file:///"+facePath+"60.gif\"/>")
+            html = string.replace(html, "/饭", "<img src=\"file:///"+facePath+"61.gif\"/>")
+            #html = string.replace(html, "/药", "<img src=\"file:///"+facePath+"62.gif\"/>")
+            html = string.replace(html, "/玫瑰", "<img src=\"file:///"+facePath+"63.gif\"/>")
+            html = string.replace(html, "/凋谢", "<img src=\"file:///"+facePath+"64.gif\"/>")
+            #html = string.replace(html, "/唇", "<img src=\"file:///"+facePath+"65.gif\"/>")
+            html = string.replace(html, "/爱心", "<img src=\"file:///"+facePath+"66.gif\"/>")
+            html = string.replace(html, "/心碎", "<img src=\"file:///"+facePath+"67.gif\"/>")
+            #html = string.replace(html, "/餐桌", "<img src=\"file:///"+facePath+"68.gif\"/>")
+            html = string.replace(html, "/礼物", "<img src=\"file:///"+facePath+"69.gif\"/>")
+            #html = string.replace(html, "/电话", "<img src=\"file:///"+facePath+"70.gif\"/>")
+            #html = string.replace(html, "/时间", "<img src=\"file:///"+facePath+"71.gif\"/>")
+            #html = string.replace(html, "/信件", "<img src=\"file:///"+facePath+"72.gif\"/>")
+            #html = string.replace(html, "/电视", "<img src=\"file:///"+facePath+"73.gif\"/>")
+            html = string.replace(html, "/太阳", "<img src=\"file:///"+facePath+"74.gif\"/>")
+            html = string.replace(html, "/月亮", "<img src=\"file:///"+facePath+"75.gif\"/>")
+            html = string.replace(html, "/强", "<img src=\"file:///"+facePath+"76.gif\"/>")
+            html = string.replace(html, "/弱", "<img src=\"file:///"+facePath+"77.gif\"/>")
+            html = string.replace(html, "/握手", "<img src=\"file:///"+facePath+"78.gif\"/>")
+            html = string.replace(html, "/胜利", "<img src=\"file:///"+facePath+"79.gif\"/>")
+            #html = string.replace(html, "/灰老鼠", "<img src=\"file:///"+facePath+"80.gif\"/>")
+            #html = string.replace(html, "/小女孩", "<img src=\"file:///"+facePath+"81.gif\"/>")
+            #html = string.replace(html, "/XXXX", "<img src=\"file:///"+facePath+"82.gif\"/>")
+            #html = string.replace(html, "/XXXX", "<img src=\"file:///"+facePath+"83.gif\"/>")
+            #html = string.replace(html, "/男Q", "<img src=\"file:///"+facePath+"84.gif\"/>")
+            html = string.replace(html, "/飞吻", "<img src=\"file:///"+facePath+"85.gif\"/>")
+            html = string.replace(html, "/怄火", "<img src=\"file:///"+facePath+"86.gif\"/>")
+            #html = string.replace(html, "/酒瓶", "<img src=\"file:///"+facePath+"87.gif\"/>")
+            #html = string.replace(html, "/可乐", "<img src=\"file:///"+facePath+"88.gif\"/>")
+            html = string.replace(html, "/西瓜", "<img src=\"file:///"+facePath+"89.gif\"/>")
+            #html = string.replace(html, "/阴雨", "<img src=\"file:///"+facePath+"90.gif\"/>")
+            #html = string.replace(html, "/多云", "<img src=\"file:///"+facePath+"91.gif\"/>")
+            #html = string.replace(html, "/雪人", "<img src=\"file:///"+facePath+"92.gif\"/>")
+            #html = string.replace(html, "/星星", "<img src=\"file:///"+facePath+"93.gif\"/>")
+            #html = string.replace(html, "/女", "<img src=\"file:///"+facePath+"94.gif\"/>")
+            #html = string.replace(html, "/男", "<img src=\"file:///"+facePath+"95.gif\"/>")
+            html = string.replace(html, "/冷汗", "<img src=\"file:///"+facePath+"96.gif\"/>")
+            html = string.replace(html, "/擦汗", "<img src=\"file:///"+facePath+"97.gif\"/>")
+            html = string.replace(html, "/抠鼻", "<img src=\"file:///"+facePath+"98.gif\"/>")
+            html = string.replace(html, "/鼓掌", "<img src=\"file:///"+facePath+"99.gif\"/>")
+            html = string.replace(html, "/糗大了", "<img src=\"file:///"+facePath+"100.gif\"/>")
+            html = string.replace(html, "/坏笑", "<img src=\"file:///"+facePath+"101.gif\"/>")
+            html = string.replace(html, "/左哼哼", "<img src=\"file:///"+facePath+"102.gif\"/>")
+            html = string.replace(html, "/右哼哼", "<img src=\"file:///"+facePath+"103.gif\"/>")
+            html = string.replace(html, "/哈欠", "<img src=\"file:///"+facePath+"104.gif\"/>")
+            html = string.replace(html, "/鄙视", "<img src=\"file:///"+facePath+"105.gif\"/>")
+            html = string.replace(html, "/委屈", "<img src=\"file:///"+facePath+"106.gif\"/>")
+            html = string.replace(html, "/快哭了", "<img src=\"file:///"+facePath+"107.gif\"/>")
+            html = string.replace(html, "/阴险", "<img src=\"file:///"+facePath+"108.gif\"/>")
+            html = string.replace(html, "/亲亲", "<img src=\"file:///"+facePath+"109.gif\"/>")
+            html = string.replace(html, "/吓", "<img src=\"file:///"+facePath+"110.gif\"/>")
+            html = string.replace(html, "/可怜", "<img src=\"file:///"+facePath+"111.gif\"/>")
+            html = string.replace(html, "/菜刀", "<img src=\"file:///"+facePath+"112.gif\"/>")
+            html = string.replace(html, "/啤酒", "<img src=\"file:///"+facePath+"113.gif\"/>")
+            html = string.replace(html, "/篮球", "<img src=\"file:///"+facePath+"114.gif\"/>")
+            html = string.replace(html, "/乒乓", "<img src=\"file:///"+facePath+"115.gif\"/>")
+            html = string.replace(html, "/示爱", "<img src=\"file:///"+facePath+"116.gif\"/>")
+            html = string.replace(html, "/瓢虫", "<img src=\"file:///"+facePath+"117.gif\"/>")
+            html = string.replace(html, "/抱拳", "<img src=\"file:///"+facePath+"118.gif\"/>")
+            html = string.replace(html, "/勾引", "<img src=\"file:///"+facePath+"119.gif\"/>")
+            html = string.replace(html, "/拳头", "<img src=\"file:///"+facePath+"120.gif\"/>")
+            html = string.replace(html, "/差劲", "<img src=\"file:///"+facePath+"121.gif\"/>")
+            html = string.replace(html, "/爱你", "<img src=\"file:///"+facePath+"122.gif\"/>")
+            html = string.replace(html, "/NO", "<img src=\"file:///"+facePath+"123.gif\"/>")
+            html = string.replace(html, "/OK", "<img src=\"file:///"+facePath+"124.gif\"/>")
+            html = string.replace(html, "/转圈", "<img src=\"file:///"+facePath+"125.gif\"/>")
+            html = string.replace(html, "/磕头", "<img src=\"file:///"+facePath+"126.gif\"/>")
+            html = string.replace(html, "/回头", "<img src=\"file:///"+facePath+"127.gif\"/>")
+            html = string.replace(html, "/跳绳", "<img src=\"file:///"+facePath+"128.gif\"/>")
+            html = string.replace(html, "/挥手", "<img src=\"file:///"+facePath+"129.gif\"/>")
+            html = string.replace(html, "/激动", "<img src=\"file:///"+facePath+"130.gif\"/>")
+            html = string.replace(html, "/街舞", "<img src=\"file:///"+facePath+"131.gif\"/>")
+            html = string.replace(html, "/献吻", "<img src=\"file:///"+facePath+"132.gif\"/>")
+            html = string.replace(html, "/左太极", "<img src=\"file:///"+facePath+"133.gif\"/>")
+            html = string.replace(html, "/右太极", "<img src=\"file:///"+facePath+"134.gif\"/>")
+            html = string.replace(html, "/黑丝带", "<img src=\"file:///"+facePath+"135.gif\"/>")
+            html = string.replace(html, "/祈福", "<img src=\"file:///"+facePath+"136.gif\"/>")
+            html = string.replace(html, "/黄丝带", "<img src=\"file:///"+facePath+"137.gif\"/>")
+            html = string.replace(html, "/百合花", "<img src=\"file:///"+facePath+"138.gif\"/>")
+            html = string.replace(html, "/糖", "<img src=\"file:///"+facePath+"150.gif\"/>")
+            html = string.replace(html, "/红包", "<img src=\"file:///"+facePath+"151.gif\"/>")
+            html = string.replace(html, "/月饼", "<img src=\"file:///"+facePath+"152.gif\"/>")
+            html = string.replace(html, "/酒", "<img src=\"file:///"+facePath+"153.gif\"/>")
+            html = string.replace(html, "/团圆饼", "<img src=\"file:///"+facePath+"154.gif\"/>")
+            html = string.replace(html, "/玉兔", "<img src=\"file:///"+facePath+"155.gif\"/>")
+            html = string.replace(html, "/蛋黄月饼", "<img src=\"file:///"+facePath+"156.gif\"/>")
+            
+        else:
+            facePath = Utils.ICONS_DIR+"face.sina/"
+            html = string.replace(html, "[满月]", "<img src=\"file:///"+facePath+"moon1.gif\"/>")
+            html = string.replace(html, "[月饼]", "<img src=\"file:///"+facePath+"mooncake3.gif\"/>")
+            html = string.replace(html, "[酒壶]", "<img src=\"file:///"+facePath+"wine.gif\"/>")
+            html = string.replace(html, "[团]", "<img src=\"file:///"+facePath+"tuan.gif\"/>")
+            html = string.replace(html, "[圆]", "<img src=\"file:///"+facePath+"yuan.gif\"/>")
+            html = string.replace(html, "[织]", "<img src=\"file:///"+facePath+"zz2.gif\"/>")
+            html = string.replace(html, "[围观]", "<img src=\"file:///"+facePath+"wg.gif\"/>")
+            html = string.replace(html, "[威武]", "<img src=\"file:///"+facePath+"vw.gif\"/>")
+            html = string.replace(html, "[给力]", "<img src=\"file:///"+facePath+"geili.gif\"/>")
+            html = string.replace(html, "[神马]", "<img src=\"file:///"+facePath+"horse2.gif\"/>")
+            html = string.replace(html, "[浮云]", "<img src=\"file:///"+facePath+"fuyun.gif\"/>")
+            html = string.replace(html, "[奥特曼]", "<img src=\"file:///"+facePath+"otm.gif\"/>")
+            html = string.replace(html, "[兔子]", "<img src=\"file:///"+facePath+"rabbit.gif\"/>")
+            html = string.replace(html, "[熊猫]", "<img src=\"file:///"+facePath+"panda.gif\"/>")
+            html = string.replace(html, "[飞机]", "<img src=\"file:///"+facePath+"travel.gif\"/>")
 
+            html = string.replace(html, "[呵呵]", "<img src=\"file:///"+facePath+"smile.gif\"/>")
+            html = string.replace(html, "[嘻嘻]", "<img src=\"file:///"+facePath+"tooth.gif\"/>")
+            html = string.replace(html, "[哈哈]", "<img src=\"file:///"+facePath+"laugh.gif\"/>")
+            html = string.replace(html, "[爱你]", "<img src=\"file:///"+facePath+"love.gif\"/>")
+            html = string.replace(html, "[晕]", "<img src=\"file:///"+facePath+"dizzy.gif\"/>")
+            html = string.replace(html, "[泪]", "<img src=\"file:///"+facePath+"sad.gif\"/>")
+            html = string.replace(html, "[馋嘴]", "<img src=\"file:///"+facePath+"cz.gif\"/>")
+            html = string.replace(html, "[抓狂]", "<img src=\"file:///"+facePath+"crazy.gif\"/>")
+            html = string.replace(html, "[哼]", "<img src=\"file:///"+facePath+"hate.gif\"/>")
+            html = string.replace(html, "[抱抱]", "<img src=\"file:///"+facePath+"bb.gif\"/>")
+            html = string.replace(html, "[可爱]", "<img src=\"file:///"+facePath+"tz.gif\"/>")
+            html = string.replace(html, "[怒]", "<img src=\"file:///"+facePath+"angry.gif\"/>")
+            html = string.replace(html, "[汗]", "<img src=\"file:///"+facePath+"sweat.gif\"/>")
+            html = string.replace(html, "[困]", "<img src=\"file:///"+facePath+"sleepy.gif\"/>")
+            html = string.replace(html, "[害羞]", "<img src=\"file:///"+facePath+"shame.gif\"/>")
 
+            html = string.replace(html, "[睡觉]", "<img src=\"file:///"+facePath+"sleep.gif\"/>")
+            html = string.replace(html, "[钱]", "<img src=\"file:///"+facePath+"money.gif\"/>")
+            html = string.replace(html, "[偷笑]", "<img src=\"file:///"+facePath+"hei.gif\"/>")
+            html = string.replace(html, "[酷]", "<img src=\"file:///"+facePath+"cool.gif\"/>")
+            html = string.replace(html, "[衰]", "<img src=\"file:///"+facePath+"cry.gif\"/>")
+            html = string.replace(html, "[吃惊]", "<img src=\"file:///"+facePath+"cj.gif\"/>")
+            html = string.replace(html, "[闭嘴]", "<img src=\"file:///"+facePath+"bz.gif\"/>")
+            html = string.replace(html, "[鄙视]", "<img src=\"file:///"+facePath+"bs2.gif\"/>")
+            html = string.replace(html, "[挖鼻屎]", "<img src=\"file:///"+facePath+"kbs.gif\"/>")
+            html = string.replace(html, "[花心]", "<img src=\"file:///"+facePath+"hs.gif\"/>")
+            html = string.replace(html, "[鼓掌]", "<img src=\"file:///"+facePath+"gz.gif\"/>")
+            html = string.replace(html, "[失望]", "<img src=\"file:///"+facePath+"sw.gif\"/>")
+            html = string.replace(html, "[思考]", "<img src=\"file:///"+facePath+"sk.gif\"/>")
+            html = string.replace(html, "[生病]", "<img src=\"file:///"+facePath+"sb.gif\"/>")
+            html = string.replace(html, "[亲亲]", "<img src=\"file:///"+facePath+"qq.gif\"/>")
+
+            html = string.replace(html, "[怒骂]", "<img src=\"file:///"+facePath+"nm.gif\"/>")
+            html = string.replace(html, "[太开心]", "<img src=\"file:///"+facePath+"mb.gif\"/>")
+            html = string.replace(html, "[懒得理你]", "<img src=\"file:///"+facePath+"ldln.gif\"/>")
+            html = string.replace(html, "[右哼哼]", "<img src=\"file:///"+facePath+"yhh.gif\"/>")
+            html = string.replace(html, "[左哼哼]", "<img src=\"file:///"+facePath+"zhh.gif\"/>")
+            html = string.replace(html, "[嘘]", "<img src=\"file:///"+facePath+"x.gif\"/>")
+            html = string.replace(html, "[委屈]", "<img src=\"file:///"+facePath+"wq.gif\"/>")
+            html = string.replace(html, "[吐]", "<img src=\"file:///"+facePath+"t.gif\"/>")
+            html = string.replace(html, "[可怜]", "<img src=\"file:///"+facePath+"kl.gif\"/>")
+            html = string.replace(html, "[打哈气]", "<img src=\"file:///"+facePath+"k.gif\"/>")
+            html = string.replace(html, "[顶]", "<img src=\"file:///"+facePath+"d.gif\"/>")
+            html = string.replace(html, "[疑问]", "<img src=\"file:///"+facePath+"yw.gif\"/>")
+            html = string.replace(html, "[握手]", "<img src=\"file:///"+facePath+"ws.gif\"/>")
+            html = string.replace(html, "[耶]", "<img src=\"file:///"+facePath+"ye.gif\"/>")
+            html = string.replace(html, "[good]", "<img src=\"file:///"+facePath+"good.gif\"/>")
+
+            html = string.replace(html, "[弱]", "<img src=\"file:///"+facePath+"sad_thumb.gif\"/>")
+            html = string.replace(html, "[不要]", "<img src=\"file:///"+facePath+"no.gif\"/>")
+            html = string.replace(html, "[ok]", "<img src=\"file:///"+facePath+"ok.gif\"/>")
+            html = string.replace(html, "[赞]", "<img src=\"file:///"+facePath+"z2.gif\"/>")
+            html = string.replace(html, "[来]", "<img src=\"file:///"+facePath+"come.gif\"/>")
+            html = string.replace(html, "[蛋糕]", "<img src=\"file:///"+facePath+"cake.gif\"/>")
+            html = string.replace(html, "[心]", "<img src=\"file:///"+facePath+"heart.gif\"/>")
+            html = string.replace(html, "[伤心]", "<img src=\"file:///"+facePath+"unheart.gif\"/>")
+            html = string.replace(html, "[钟]", "<img src=\"file:///"+facePath+"clock.gif\"/>")
+            html = string.replace(html, "[猪头]", "<img src=\"file:///"+facePath+"pig.gif\"/>")
+            html = string.replace(html, "[话筒]", "<img src=\"file:///"+facePath+"m.gif\"/>")
+            html = string.replace(html, "[月亮]", "<img src=\"file:///"+facePath+"moon.gif\"/>")
+            html = string.replace(html, "[下雨]", "<img src=\"file:///"+facePath+"rain.gif\"/>")
+            html = string.replace(html, "[太阳]", "<img src=\"file:///"+facePath+"sun.gif\"/>")
+            html = string.replace(html, "[微博蛋糕]", "<img src=\"file:///"+facePath+"weibo2zhounian.gif\"/>")
+            html = string.replace(html, "[蜡烛]", "<img src=\"file:///"+facePath+"lazu.gif\"/>")
+        return html
 
     def update_content_html(self, contentHtml=None, baseUrl=None):
 #        settings=self.settings()
@@ -1692,8 +1996,8 @@ class getTokenAccessForm(QDialog):
     def openBrowser(self):
         try:
             import os
-            print "open browser..."
-            print self.auth_url
+            #print "open browser..."
+            #print self.auth_url
             # maebo browser have a bug!
             #os.system('browser --url="' + self.auth_url + '"')
             os.system('dbus-send --system --type=method_call --dest=com.nokia.osso_browser /com/nokia/osso_browser/request com.nokia.osso_browser.load_url string:"' + self.auth_url + '"')
@@ -1704,6 +2008,83 @@ class getTokenAccessForm(QDialog):
     def show_notice(self,message,timeout=QMaemo5InformationBox.DefaultTimeout):
         QMaemo5InformationBox.information(None,"\n"+unicode(message)+"\n",timeout)
 
+class SettingForm(QDialog):
+    def __init__(self, parent=None, settings=None):
+        super(SettingForm, self).__init__(parent)
+        self.setWindowTitle(unicode("微博设置"))
+        
+        self.label_updatenum = QLabel(unicode("每次更新条数："))
+        self.label_downpic = QLabel(unicode("是否下载图片："))
+        
+        self.InputUpdateNum = QLineEdit(self)
+        self.InputUpdateNum.setObjectName("InputUpdateNum")
+        self.InputUpdateNum.setFixedWidth(100)
+        self.InputUpdateNum.setText(settings["updatenum"])
+        
+        self.radiogroup = QGroupBox(self)
+        #self.radiogroup.setFixedHeight(30)
+        
+        self.label_radio = QRadioButton(unicode("下载微博图片及用户头像"), self.radiogroup)
+        self.label_radio.setFixedHeight(35)
+        if settings["downpic"]=="True":
+            self.label_radio.setChecked(True)
+        else:
+            self.label_radio.setChecked(False)
+        
+        self.formLayout=QFormLayout(self)
+        self.formLayout.setAlignment(Qt.AlignTop)
+        self.formLayout.addRow(self.label_downpic, self.radiogroup)
+        self.formLayout.addRow(self.label_updatenum, self.InputUpdateNum)
+        
+        self.confirmButton = QPushButton(unicode("确定"))
+        self.cancelButton = QPushButton(unicode("取消"))
+        self.confirmButton.setFixedWidth(150)
+        self.cancelButton.setFixedWidth(150)
+        
+        self.connect(self.cancelButton,
+                     SIGNAL("clicked()"),
+                     self.hide)
+        
+        
+        self.buttonFormLayout=QFormLayout(self)
+        self.buttonFormLayout.setAlignment(Qt.AlignTop)
+        self.buttonFormLayout.addRow(self.confirmButton)
+        self.buttonFormLayout.addRow(self.cancelButton)
+        
+        self.mainFrame=QFrame()
+        self.mainFrame.setLayout(self.formLayout)
+        
+        self.buttonFrame=QFrame()
+        self.buttonFrame.setLayout(self.buttonFormLayout)
+        
+        self.outerLayout = QGridLayout(self)
+        self.outerLayout.setObjectName("outerLayout")
+        self.outerLayout.addWidget(self.mainFrame,0,0)
+        self.outerLayout.addWidget(self.buttonFrame,0,1)
+        self.outerLayout.setAlignment(self.formLayout,Qt.AlignTop)
+
+
+    def validate(self,callback):
+        if self.InputUpdateNum.text() is None or self.InputUpdateNum.text()=="":
+            callback(unicode("请输入每次更新微博条数！"))
+            return 0
+            
+        inputnum = int(self.InputUpdateNum.text())
+        if inputnum < 5 or inputnum > 50:
+            callback(unicode("请输入5-50之间的数字！"))
+            return 0
+            
+        return 1
+
+    def output_account(self,callback):
+        if self.validate(callback):
+            self.setting = {}
+            self.setting["updatenum"]=str(self.InputUpdateNum.text())
+            self.setting["downpic"]=str(self.label_radio.isChecked())
+
+            return self.setting
+        else:
+            return None
 
 class AboutForm(QDialog):
     def __init__(self, parent=None):
@@ -1726,6 +2107,35 @@ class AboutForm(QDialog):
         self.formLayout=QFormLayout(self)
         self.formLayout.addRow(self.aboutLabel)
 
+
+class DefaultWindow(QMainWindow):
+    def __init__(self, parent=None, accounts=None, websites=None , orientation=0):
+        super(DefaultWindow, self).__init__(parent)
+        self.setWindowTitle("Maebo")
+        
+        self.orientation=orientation
+        self.setAttribute(Qt.WA_Maemo5StackedWindow)
+        
+        st="""
+            <div style="color:#444;padding-left:10px;">
+                欢迎您使用 <b>Maebo</b>！<br />
+                Maebo是一款支持腾讯及新浪微博的手机客户端程序。<br />
+                该客户端专为Nokia N900 Maemo系统量身定做开发。<br />
+                在此特别感谢dospy.com论坛N900专区各位机友的长期支持。<br />
+                如果您在Maebo使用过程中遇到问题，可以前往dospy论坛N900专区；<br />
+                或者收听我的微博 t.qq.com/bink  weibo.com/binkcn 向我反馈。<br /><br />
+                <b>请点击顶部菜单开始添加绑定您的微博账户。</b><br />
+            </div>
+            """
+        self.aboutLabel=QLabel()
+        self.aboutLabel.setText(st)
+        
+        self.setCentralWidget(self.aboutLabel)
+        self.centralWidget().setStyleSheet("background-color: "+Utils.COLOR_BACKGROUND);
+        
+        self.setFixedSize(800,480)
+
+
 #class LogWindow(QMainWindow):
 #    def __init__(self, parent=None):
 #        super(LogWindow, self).__init__(parent)
